@@ -6,7 +6,7 @@ use Moose::Autobox;
 use Moose::Util::TypeConstraints qw(enum);
 use namespace::autoclean;
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 with 'Dist::Zilla::Role::Releaser',
      'Dist::Zilla::Role::FilePruner';
@@ -109,15 +109,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::RPM - Build an RPM from your Dist::Zilla release
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -128,6 +131,8 @@ In your dist.ini:
     sign = 1
     ignore_build_deps = 0
 
+After adding the [RPM] section to the dist.ini file, the mkrpmspec command will be available. Running this command allow you to make the dzil.spec file from the template. Then dzil release will make the RPM file.
+
 =head1 DESCRIPTION
 
 This plugin is a Releaser for Dist::Zilla that builds an RPM of your
@@ -166,6 +171,8 @@ If set to a true value, rpmbuild will be called with the --sign option.
 
 =back
 
+=over
+
 =item ignore_build_deps (default: False)
 
 If set to a true value, rpmbuild will be called with the --nodeps option.
@@ -183,7 +190,6 @@ If set to a true value, rpmbuild will be called with the --nodeps option.
     Group: Applications/CPAN
     BuildArch: noarch
     URL: <% $zilla->license->url %>
-    Vendor: <% $zilla->license->holder %>
     Source: <% $archive %>
     
     BuildRoot: %{_tmppath}/%{name}-%{version}-BUILD
@@ -219,14 +225,13 @@ L<Dist::Zilla|Dist::Zilla>
 
 =head1 AUTHOR
 
-Stephen Clouse <stephenclouse@gmail.com>
+Vincent Lequertier <sky@riseup.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Stephen Clouse.
+This software is copyright (c) 2015 by vincent Lequertier.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
